.. JWST Rogue Path Tool documentation master file, created by
   sphinx-quickstart on Thu Sep 26 14:57:45 2024.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

JWST Rogue Path Tool documentation
==================================

Module to predict the presence of the stray-light artifacts know as claws in NIRCam Imaging observations.

API documentation
=================

.. toctree::
   :maxdepth: 1
   :caption: Contents:

   jwst_rogue_path_tool
   original_src
   scripts

